*! version 1.0.0 June 22, 2018 @ 04:02:58
*! makes a putdocx document
version 15.1
set more off 
capture log close putwrap
log using putwrap, name(putwrap) replace

** need a code definition
local code font("Courier New",,"0000aa") // blue to look nice

capture putdocx clear  // in case last compile failed
** start accumulating the document
putdocx begin

This is a meant to be a very simple exposition about modeling energy usage using Stata's auto dataset.
To make things work more nicely, let's pretend that this is some sort of sample of measurements, so that when we talk about average energy consumption, it will make some sense.

We'll open the 
putdocx text ("auto"), bold
 dataset, and look at its structure behind the scenes.
The 
putdocx text ("putdocx"), `code'
 command cannot not show Stata code or output in general.
It instead is made for putting tables and other output into a report, without showing any Stata code.
So, we'll have to do some work, and then report just the results.
putdocx pause
*none of this will either be seen as input or as output
  sysuse auto, clear
  describe
  tabstat price mpg weight displacement, ///
  statistics( count mean sd min p25 p50 p75 max ) ///
  save
* we need to make a new matrix to be sure that putdocx gets the names right
  matrix Stats = r(StatTotal)'
putdocx resume

Here are some summary statisticsa about 1978 automobiles:
putdocx table tabstat1 = matrix(Stats), rownames colnames

For those unfamiliar with the system of weights and measures used in the United Stated (and Liberia), the important conversions to remember are that

putdocx paragraph, indent(left, 0.5cm)
putdocx text ("1 mile = 1605 meters = 1.605 km"), linebreak(1)
putdocx text ("1 pound = 454.6 grams = 0.4546 kg"), linebreak(1)
putdocx text ("1 gallon = 3.7854 liters or about 15/4 liters"), linebreak(1)
putdocx text ("1 inch = 2.54 cm"), linebreak(1)
putdocx text ("Hence 1 cubic inch = 16.387064 cc or about 16 3/8 cc"), linebreak(1)
putdocx text ("1 foot = 12 inches = 30.48cm"), linebreak(1)
putdocx text ("Hence 1 cubic foot = 28316.847 cc or about 28 1/3 liters"), linebreak(1)

One other oddity in the so-called traditional (or Standard or English or Imperial) system, is that energy usage is measured in miles per gallon (mpg).
This is not good for analysis, because it makes for a non-linear relationship between weight and energy. This can be seen in following graph:
putdocx pause
twoway (scatter mpg weight), title(Non-linearity mpg on weight)
graph export mpg_wt.png, replace
putdocx paragraph, halign(center)
putdocx image mpg_wt.png, height(10cm)
putdocx resume

To make the analysis work better, we will make a variable measuring gallons use per 100 miles driven.
putdocx pause
gen gp100m = 100/mpg, before(mpg)
label variable gp100m "Gallons per 100 miles"
putdocx resume
 This requires one last conversion: 1 gallon per 100 miles is about 75/32 (= `:display %5.3f 75/32') liters per 100 km.

Let's take a look at various variables by whether the cars are from the US (
putdocx text ("domestic"), italic
) or whether they are from outside the US (
putdocx text ("foreign"), italic
).
putdocx pause
tabstat gp100m weight length turn displacement gear_ratio, ///
  statistics( mean sd count ) by(foreign) save
matrix Stats = r(StatTotal)'
putdocx resume
putdocx table tabstat2 = matrix(Stats), rownames colnames

Before modelling, we should take a look to see if there could be collinearities in the predictors.
putdocx pause

* graph matrix gp100m weight length turn displacement gear_ratio
* graph export graph_mat.png, replace

* putdocx paragraph, halign(center)
* putdocx image graph_mat.png, height(10cm)

putdocx resume

Finally, how about modelling let's first run a regression with many variables
putdocx pause
regress gp100m weight displacement gear_ratio foreign
putdocx table regress1 = etable
estimates store e_wdgf
putdocx resume

We can see that, as expected, heavier cars take more energy to move, an that, as not expected, non-US cars use more gas at the same weight.
It appears that we can throw out both 
putdocx text ("displacement"), `code'
putdocx text (" and ")
putdocx text ("gear_ratio"), `code'
 as predictors and fit a simpler model.

putdocx pause
regress gp100m weight foreign
putdocx table regress1 = etable
estimates store e_wf
putdocx resume
	
We can put these coefficients in a table

putdocx save "putwrap", replace
putdocx append putwrap twoetable, saving(putwrap, replace)
putdocx begin

From the simple model, cars from 40 years ago used `: display %5.3f _b[weight]*100' gallons per mile per extra 100 pounds, on average.
Also, non-US cars use about `: display %5.3f _b[foreign]'
more gallons per mile, on average, all other things being equal.

putdocx save "putwrap", append
putdocx pause

log close putwrap
