*! version 1.0.0 December 6, 2018 @ 23:56:32
*! makes a putdocx document
version 15.1
set more off 
capture log close putdocx
log using putdocx, name(putdocx) replace

** need a code definition
local code font("Courier New",,"0000aa") // blue to look nice

capture putdocx clear  // in case last compile failed
** start accumulating the document
putdocx begin

putdocx paragraph, style(Title)
putdocx text ("Energy Usage in 1978 Automobiles")

putdocx paragraph
putdocx text ("This is a meant to be a very simple exposition about modeling energy usage using Stata's auto dataset.")
putdocx text (" What makes the dataset special is that it is from the year 1978.")
putdocx text (" Notable occurrences in 1978 were few, though there were three popes, OPEC was at its height, and homebrewing of beer was legalized in the U.S.")
putdocx text (`" To make things work more nicely, let's pretend that this is some sort of sample of measurements, so that when we talk about "average energy consumption", it will make some sense."')

putdocx paragraph
putdocx text ("We'll open the ")
putdocx text ("auto"), bold
putdocx text (" dataset, and look at its structure behind the scenes.")
putdocx text (" The ")
putdocx text ("putdocx"), `code'
putdocx text (" command cannot not show Stata code or output in general.")
putdocx text (" It instead is made for putting tables and other output into a report, without showing any Stata code.")
putdocx text (" So, we'll have to do some work, and then report just the results.")

*** none of this will either be seen as input or as output
sysuse auto, clear
describe
tabstat price mpg weight displacement, ///
  statistics( count mean sd min p25 p50 p75 max ) ///
  save
* we need to make a new matrix to be sure that putdocx gets the names right
matrix Stats = r(StatTotal)'

putdocx paragraph
putdocx text ("Here are some summary statistics about 1978 automobiles:")

putdocx table tabstat1 = matrix(Stats), rownames colnames

putdocx paragraph
putdocx text ("For those unfamiliar with the system of weights and measures used in the United States (and Liberia), the important conversions to remember are that")

putdocx paragraph, indent(left, 0.5cm)
putdocx text ("1 mile = 1605 meters = 1.605 km"), linebreak(1)
putdocx text ("1 pound = 454.6 grams = 0.4546 kg"), linebreak(1)
putdocx text ("1 gallon = 3.7854 liters or about 15/4 liters"), linebreak(1)
putdocx text ("1 inch = 2.54 cm"), linebreak(1)
putdocx text ("Hence 1 cubic inch = 16.387064 cc or about 16 3/8 cc"), linebreak(1)
putdocx text ("1 foot = 12 inches = 30.48cm"), linebreak(1)
putdocx text ("Hence 1 cubic foot = 28316.847 cc or about 28 1/3 liters"), linebreak(1)

putdocx paragraph
putdocx text ("One other oddity in the so-called traditional (or Standard or English or Imperial) system, is that energy usage is measured in miles per gallon (mpg).")
putdocx text (" This is not good for analysis, because it makes for a non-linear relationship between weight and energy. This can be seen in following graph:")

twoway (scatter mpg weight), title(Non-linearity mpg on weight)
graph export mpg_wt.png, replace

putdocx paragraph, halign(center)
putdocx image mpg_wt.png, height(10cm)


putdocx paragraph
putdocx text ("To make the analysis work better, we will make a variable measuring gallons use per 100 miles driven.")

gen gp100m = 100/mpg, before(mpg)
label variable gp100m "Gallons per 100 miles"

putdocx text (" This requires one last conversion: 1 gallon per 100 miles is about 75/32 (= `:display %5.3f 75/32') liters per 100 km.")

putdocx paragraph
putdocx text ("Let's take a look at various variables by whether the cars are from the US (")
putdocx text ("domestic"), italic
putdocx text (") or whether they are from outside the US (")
putdocx text ("foreign"), italic
putdocx text (").")
putdocx text ("This was 1978, so country of manufacture mostly matched location of company. This is, of course, no longer the case.")

tabstat gp100m weight length turn displacement gear_ratio, ///
  statistics( mean sd count ) by(foreign) save
matrix Stats = r(Stat1)'
putdocx table domestic = matrix(Stats), rownames colnames title(Domestic)
matrix Stats = r(Stat2)'
putdocx table foreign = matrix(Stats), rownames colnames title(Foreign)
matrix Stats = r(StatTotal)'
putdocx table overall = matrix(Stats), rownames colnames title(Overall)


putdocx paragraph
putdocx text ("Before modelling, we should take a look to see if there could be collinearities in the predictors.")

/*
graph matrix gp100m weight length turn displacement gear_ratio
graph export graph_mat.png, replace

putdocx paragraph, halign(center)
putdocx image graph_mat.png, height(10cm)
*/

putdocx paragraph
putdocx text ("Finally, how about modelling? Let's first run a regression with many variables:")

regress gp100m weight displacement gear_ratio foreign
putdocx table regress1 = etable
estimates store e_wdgf

putdocx paragraph
putdocx text ("We can see that, as expected, heavier cars take more energy to move, an that, as not expected, non-US cars use more gas at the same weight.")
putdocx text (" It appears that we can throw out both ")
putdocx text ("displacement"), `code'
putdocx text (" and ")
putdocx text ("gear_ratio"), `code'
putdocx text (" as predictors and fit a simpler model.")

regress gp100m weight foreign
putdocx table regress1 = etable
estimates store e_wf

	
putdocx paragraph
putdocx text ("We can put these coefficients in a table")

putdocx save "putdocx", replace

reg2docx e_wdgf e_wf using twoetable.docx, replace

putdocx append putdocx twoetable, saving(putdocx, replace)

putdocx begin

putdocx paragraph

putdocx text ("From the simple model, cars from `= yofd(date(`"`c(current_date)'"',"DMY")) - 1978' years ago used ")
putdocx text ("`: display %5.3f _b[weight]*100'")
putdocx text (" gallons per 100 miles per extra 100 pounds, on average.")
putdocx text (" Also, non-US cars use about ")
putdocx text ("`: display %5.3f _b[foreign]'")
putdocx text (" more gallons per 100 miles, on average, all other things being equal.")

putdocx save "putdocx", append
log close putdocx
